#!/usr/bin/env python
# encoding: utf-8

GRADES_FILENAME = 'grades.csv'
SUBMISSIONS_FILENAME = 'Submissions'
SUBMISSION_LISTING_END = '_submission'
GRADING_URL_EXTENSION = '&action=grading'
GRADING_SLASH_DELIMINATOR = '/'
GRADING_BLANK_GRADE = '-'
GRADING_HEADER_NAME = 'Name'
GRADING_HEADER_EMAIL = 'Email'
GRADING_HEADER_GRADE = 'Grade'
