#!/usr/bin/env python
# encoding: utf-8

DIV = 'div'
LINK = 'a'
LIST = 'li'
TABLE = 'td'
SPAN = 'span'
CLASS = 'class'
TITLE = 'title'
HEADING3 = 'h3'
LINKTEXT = 'href'
LABEL = 'aria-label'

ENCODING = 'utf-8'

OPTION = 'option'
NAME_ID = 'id_name'
LOGIN_ID = 'loginbtn'
USERNAME_ID = 'username'
PASSWORD_ID = 'password'
SUBMIT_ID = 'id_submitbutton'
SUBMIT2_ID = 'id_submitbutton2'
DEFAULT_NAME_ID = 'id_usedefaultname'

LOGIN = 'login'
FILTER = 'id_filter'
MODULES = 'mymodules'
PERPAGE = 'id_perpage'
FIRST_CELL = 'cell c0'
THIRD_CELL = 'cell c2'
FIFTH_CELL = 'cell c5'
SUBMIT = 'submitbutton'
UPLOAD = 'fp-upload-btn'
FILE = 'input[type="file"]'
FILE_CONTENT = 'fp-mainfile'
INSTANCE = 'activityinstance'
CONFIRM = 'fp-dlg-butconfirm'
EDIT_SUMMARY = 'Edit summary'
DELETE_FILE = 'fp-file-delete'
INSTANCE_NAME = 'instancename'
COURSE_CONTENT = 'course-content'
THIRD_CELL_EMAIL = 'cell c3 email'
SECTION = 'section-modchooser-text'
INCREASE_SECTIONS = 'increase-sections'
COURSES = 'courses frontpage-course-list-all'
